<?php
// $Id: template.php,v 1.16.2.3 2010/05/11 09:41:22 goba Exp $


/**
* Implementation of hook_theme.
*
* Register custom theme functions.
*/
function ideastream_theme() {
  return array(
    // The form ID.
    'user_login_block' => array(
      // Forms always take the form argument.
      'arguments' => array('form' => NULL),
    ),
  );
}

/**
 * Sets the body-tag class attribute.
 *
 * Adds 'sidebar-left', 'sidebar-right' or 'sidebars' classes as needed.
 */
function phptemplate_body_class($left, $right) {
  if ($left != '' && $right != '') {
    $class = 'sidebars';
  }
  else {
    if ($left != '') {
      $class = 'sidebar-left';
    }
    if ($right != '') {
      $class = 'sidebar-right';
    }
  }

  if (isset($class)) {
    print ' class="'. $class .'"';
  }
}

/**
 * Return a themed breadcrumb trail.
 *
 * @param $breadcrumb
 *   An array containing the breadcrumb links.
 * @return a string containing the breadcrumb output.
 */
function phptemplate_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
    return '<div class="breadcrumb">'. implode(' › ', $breadcrumb) .'</div>';
  }
}

/**
 * Override or insert PHPTemplate variables into the templates.
 */
function phptemplate_preprocess_page(&$vars) {
  $vars['tabs2'] = menu_secondary_local_tasks();

  // Hook into color.module
  if (module_exists('color')) {
    _color_page_alter($vars);
  }
}

/**
 * Add a "Comments" heading above comments except on forum pages.
 */
function ideastream_preprocess_comment_wrapper(&$vars) {
  if ($vars['content'] && $vars['node']->type != 'forum') {
//    var_dump($vars['node']);
//    print 'dupa dupadupa dupa';

/*	if (module_exists('opal')) { //if OPAL module is loaded show opinion mined statistics
    $vars['content'] = '<h2 class="comments">'. t('Comments') .'</h2>'.' <div class="opal-statistics">(<div class="opal-statistics-positive">Positive:'.$vars['node']->opal_values['#positive'].'</div>, <div class="opal-statistics-negative">Negative:'.$vars['node']->opal_values['#negative'].'</div>, <div class="opal-statistics-neutral">Neutral:'.$vars['node']->opal_values['#neutral'].'</div>)</div>'. $vars['content'];
	} else */
    $vars['content'] = '<h2 class="comments">'. t('Comments') .'</h2>' . $vars['content'];
  }
}

/**
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs. Overridden to split the secondary tasks.
 *
 * @ingroup themeable
 */
function phptemplate_menu_local_tasks() {
  return menu_primary_local_tasks();
}

/**
 * Returns the themed submitted-by string for the comment.
 */
function phptemplate_comment_submitted($comment) {
  return t('!datetime — !username',
    array(
      '!username' => theme('username', $comment),
      '!datetime' => format_date($comment->timestamp)
    ));
}

/**
 * Returns the themed submitted-by string for the node.
 */
function phptemplate_node_submitted($node) {
  return t('!datetime — !username',
    array(
      '!username' => theme('username', $node),
      '!datetime' => format_date($node->created),
    ));
}

/**
 * Generates IE CSS links for LTR and RTL languages.
 */
function phptemplate_get_ie_styles() {
  global $language;

  $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . path_to_theme() .'/fix-ie.css" />';
  if ($language->direction == LANGUAGE_RTL) {
    $iecss .= '<style type="text/css" media="all">@import "'. base_path() . path_to_theme() .'/fix-ie-rtl.css";</style>';
  }

  return $iecss;
}

/**
 * Generates IE 7 CSS links
 */
function phptemplate_get_ie7_styles() {

  $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . path_to_theme() .'/fix-ie7.css" />';

  return $iecss;
}

/*
 * Search form customization
 */
 
function ideastream_preprocess_search_block_form(&$vars, $hook) {
	// Modify elements of the search form
	unset($vars['form']['search_block_form']['#title']);

	// Set a default value for the search box
  $vars['form']['search_block_form']['#value'] = t('Search ideas...');
	
	// Add a custom class to the search box
	// Set yourtheme.css > #search-block-form .form-text { color: #888888; }
  $vars['form']['search_block_form']['#attributes'] = array(
  	 'onblur' => "if (this.value == '') {this.value = '".$vars['form']['search_block_form']['#value']."';} this.style.color = '#000000';", 
		 'onfocus' => "if (this.value == '".$vars['form']['search_block_form']['#value']."') {this.value = '';} this.style.color = '#000000';" );

	// Modify elements of the submit button
	unset($vars['form']['submit']);

	// Change text on the submit button
	//$vars['form']['submit']['#value'] = t('Go!');

	// Change submit button into image button - NOTE: '#src' leading '/' automatically added
	$vars['form']['submit']['image_button'] = null; //array('#type' => 'image_button', '#src' => 'sites/all/themes/yourtheme/images/search-button.png');

	// Rebuild the rendered version (search form only, rest remains unchanged)
  unset($vars['form']['search_block_form']['#printed']);
  $vars['search']['search_block_form'] = drupal_render($vars['form']['search_block_form']);

	// Rebuild the rendered version (submit button, rest remains unchanged)
	unset($vars['form']['submit']['#printed']);
	$vars['search']['submit'] = drupal_render($vars['form']['submit']);
	
	// Collect all form elements to print entire form
  $vars['search_form'] = implode($vars['search']);
}


/**
* Theme override for user login block.
*
* The function is named themename_formid.
*/
function ideastream_user_login_block($form) {
  $form['name']['#title'] = '';
  $form['name']['#title'] = ''; //wrap any text in a t function
  $form['pass']['#title'] = ''; 
  $form['pass']['#suffix'] = '';
  
  $form['name']['#value'] = "Username";
  $form['pass']['#value'] = "Password";
  
  if (!preg_match('/\bmsie 7/i', $_SERVER['HTTP_USER_AGENT'])) {
	  $form['pass']['#type'] = "textfield";
	  
  	  $form['name']['#attributes']['OnClick'] = 'this.value=""';
	  $form['pass']['#attributes']['OnClick'] = 'this.value=""; this.type="password";';
  	  $form['pass']['#attributes']['OnFocus'] = 'this.value=""; this.type="password";';
  } else //in internet explorer 7 changing input type does not work so always keep the input as password
  {  		
  	  //$form['name']['#value'] = "";
  	  $form['name']['#attributes']['OnClick'] = 'this.value=""';
	  $form['pass']['#attributes']['OnClick'] = 'this.value="";';
  	  $form['pass']['#attributes']['OnFocus'] = 'this.value="";';
  }

  

  unset($form['links']['#value']); //remove links under fields
  //print_r($form);
  return (drupal_render($form));
}

/*********** Helper functions **********/

function _taxonomy_get_real_tree($vid){
  $innovation_ids = array();
  $object_ids = array();
  $trigger_ids = array();
  $proposal_ids = array();
  
  $tid_to_id = array(); // table that translated tids to ids in taxonomy_get_tree table
  $result_tree = array();
  $taxonomy_tree = taxonomy_get_tree($vid);
  $terms = array();
  $i=0;
  foreach($taxonomy_tree as $term){
  	$tid_to_id[$term->tid] = $i;
  	if ($term->name=='Innovation' || in_array($term->parents[0],$innovation_ids)) 
  		{ 
  			array_push($innovation_ids,$term->tid);
  			$result_tree[$term->tid]='Innovation';
  		}
  	if ($term->name=='Object' || in_array($term->parents[0],$object_ids)) 
  		{ 
  			array_push($object_ids,$term->tid);
  			$result_tree[$term->tid]='Object';
  		}
  	if ($term->name=='ProposalType' || in_array($term->parents[0],$proposal_ids)) 
  		{ 
  			array_push($proposal_ids,$term->tid);
  			$result_tree[$term->tid]='ProposalType';
  		}
  	if ($term->name=='Trigger' || in_array($term->parents[0],$trigger_ids)) 
  		{ 
  			array_push($trigger_ids,$term->tid);
  			$result_tree[$term->tid]='Trigger';
  		}
  	$i++;
  }
  //var_dump($tid_to_id);
  return array($result_tree, $taxonomy_tree, $tid_to_id);
}

/* @param $taxonomy_tree array with taxonomy tree 
   @return array with tid as key and string with path to root as value (for every term)
*/
function _taxonomy_get_path($taxonomy_tree, $tid_to_id){
  
  $term_paths = array();
  $path = "";
  foreach($taxonomy_tree as $term){
  		$path = "";
  		if (isset($term->parents[0]))
  		{
  			$term2 = $taxonomy_tree[$tid_to_id[$term->parents[0]]];
  			if ($term2->name!='Innovation' && $term2->name!='Object' && $term2->name!='Trigger' && $term2->name!='ProposalType')
  				$path .= $term2->name;
  			while (isset($term2->parents[0])) {
  				$term2 = $taxonomy_tree[$tid_to_id[$term2->parents[0]]];
  				if ($term2->name!='Innovation' && $term2->name!='Object' && $term2->name!='Trigger' && $term2->name!='ProposalType')
  					$path = $term2->name . '/ ' . $path;
  			}
  		}
  		if (substr($path, 0, 1)=='/') $path = substr($path, 2);
  		if ($path==FALSE) $path="";
  		$term_paths[$term->tid] = $path;	
  }
  return $term_paths;
}